@@ -24,8 +24,9 @@
 #define __E_BOOK_BACKEND_COUCHDB_H__
 
 #include <couchdb-glib.h>
-#include <couchdb-document-contact.h>
+#include <desktopcouch-glib.h>
 #include <libedata-book/e-book-backend.h>
+#include <libedata-book/e-book-backend-cache.h>
 
 #define E_TYPE_BOOK_BACKEND_COUCHDB        (e_book_backend_couchdb_get_type ())
 #define E_BOOK_BACKEND_COUCHDB(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), E_TYPE_BOOK_BACKEND_COUCHDB, EBookBackendCouchDB))
@@ -37,8 +38,10 @@
 typedef struct {
 	EBookBackend parent_object;
 
-	CouchDB *couchdb;
+	CouchdbSession *couchdb;
+	EBookBackendCache *cache;
 	char *dbname;
+	gboolean using_desktopcouch;
 } EBookBackendCouchDB;
 
 typedef struct {
